.. lstmcpipe documentation master file, created by
   sphinx-quickstart on Thu Dec 16 09:27:21 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.



.. include:: ../README.rst

lstmcpipe API documentation
===========================

.. toctree::
   :maxdepth: 3

   productions
   pipeline
   api/lstmcpipe



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
